sequencetools.sum_consecutive_sequence_elements_by_sign
=======================================================

.. autofunction:: abjad.tools.sequencetools.sum_consecutive_sequence_elements_by_sign.sum_consecutive_sequence_elements_by_sign
